@@ -3,12 +3,15 @@ from socket import timeout
 try:
     import urllib.request as urllib_request
     from urllib.parse import urlencode
-    from urllib.error import URLError
+    from urllib.error import HTTPError
 except ImportError: # Python 2
     import urllib2 as urllib_request
-    from urllib2 import URLError
+    from urllib2 import HTTPError
     from urllib import urlencode
 
+from .exceptions import SendGridClientError, SendGridServerError
+
+
 class SendGridClient(object):
 
     """SendGrid API."""
@@ -21,6 +24,13 @@ class SendGridClient(object):
             username: SendGrid username
             password: SendGrid password
             user: Send mail on behalf of this user (web only)
+            raise_errors: If set to False (default): in case of error, `.send`
+                method will return a tuple (http_code, error_message). If set
+                to True: `.send` will raise SendGridError. Note, from version
+                1.0.0, the default will be changed to True, so you are
+                recommended to pass True for forwards compatability.
+
+
 
         """
         self.username = username
@@ -29,6 +39,7 @@ class SendGridClient(object):
         self.port = str(opts.get('port', '443'))
         self.endpoint = opts.get('endpoint', '/api/mail.send.json')
         self.mail_url = self.host + ':' + self.port + self.endpoint
+        self._raise_errors = opts.get('raise_errors', False)
         # urllib cannot connect to SSL servers using proxies
         self.proxies = opts.get('proxies', None)
 
@@ -64,18 +75,40 @@ class SendGridClient(object):
                 values['files[' + filename + ']'] = message.files[filename]
         return values
 
+    def _make_request(self, message):
+        if self.proxies:
+            proxy_support = urllib_request.ProxyHandler(self.proxies)
+            opener = urllib_request.build_opener(proxy_support)
+            urllib_request.install_opener(opener)
+        data = urlencode(self._build_body(message), True).encode('utf-8')
+        req = urllib_request.Request(self.mail_url, data)
+        response = urllib_request.urlopen(req, timeout=10)
+        body = response.read()
+        return response.getcode(), body
+
     def send(self, message):
+        if self._raise_errors:
+            return self._raising_send(message)
+        else:
+            return self._legacy_send(message)
+
+    def _legacy_send(self, message):
         try:
-            if self.proxies:
-                proxy_support = urllib_request.ProxyHandler(self.proxies)
-                opener = urllib_request.build_opener(proxy_support)
-                urllib_request.install_opener(opener)
-            data = urlencode(self._build_body(message), True).encode('utf-8')
-            req = urllib_request.Request(self.mail_url, data)
-            response = urllib_request.urlopen(req, timeout = 10)
-            body = response.read()
-            return response.getcode(), body
-        except URLError as e:
+            return self._make_request(message)
+        except HTTPError as e:
             return e.code, e.read()
         except timeout as e:
             return 408, e
+
+    def _raising_send(self, message):
+        try:
+            self._make_request(message)
+        except HTTPError as e:
+            if e.code in range(400, 500):
+                raise SendGridClientError(e.code, e.read())
+            elif e.code in range(500, 600):
+                raise SendGridServerError(e.code, e.read())
+            else:
+                assert False
+        except timeout as e:
+            raise SendGridClientError(408, 'Request timeout')
